.. vedis-python documentation master file, created by
   sphinx-quickstart on Mon Jun 16 23:34:38 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

vedis-python
============

Python bindings for `Vedis <http://vedis.symisc.net/>`_, a fast, embedded, NoSQL database modeled after `Redis <http://redis.io>`_.

The source code for vedis-python is `hosted on GitHub <https://github.com/coleifer/vedis-python>`_.

.. note::
  If you encounter any bugs in the library, please `open an issue <https://github.com/coleifer/vedis-python/issues/new>`_, including a description of the bug and any related traceback.

Contents:

.. toctree::
   :maxdepth: 2
   :glob:

   installation
   quickstart
   api
   custom_commands


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

